diff lisp/help-macro.el @ 5567:3bc58dc9d688

Replace #'flet by #'labels where appropriate, core code. lisp/ChangeLog addition: 2011-09-07 Aidan Kehoe <kehoea@parhasard.net> * simple.el (transpose-subr): * specifier.el (let-specifier): * specifier.el (derive-device-type-from-tag-set): * test-harness.el (batch-test-emacs): * x-compose.el (alias-colon-to-doublequote): * mule/chinese.el (make-chinese-cns11643-charset): * mule/mule-cmds.el (set-locale-for-language-environment): * mule/mule-cmds.el (set-language-environment-coding-systems): * mule/mule-x-init.el (x-use-halfwidth-roman-font): * about.el (about-xemacs): * about.el (about-hackers): * diagnose.el (show-memory-usage): * diagnose.el (show-object-memory-usage-stats): * diagnose.el (show-mc-alloc-memory-usage): * diagnose.el (show-gc-stats): * dialog.el (make-dialog-box): * faces.el: * faces.el (Face-frob-property): * faces.el (set-face-stipple): * glyphs.el: * glyphs.el (init-glyphs): Removed. * help-macro.el (make-help-screen): * info.el (Info-construct-menu): * keymap.el (key-sequence-list-description): * lisp-mode.el (construct-lisp-mode-menu): * loadhist.el (unload-feature): * minibuf.el (get-user-response): * mouse.el (default-mouse-track-check-for-activation): * mouse.el (mouse-track-insert-1): Follow my own advice from the last commit and use #'labels instead of #'flet in core code.
author Aidan Kehoe <kehoea@parhasard.net>
date Wed, 07 Sep 2011 21:21:36 +0100
parents 308d34e9f07d
children
line wrap: on
line diff
--- a/lisp/help-macro.el	Wed Sep 07 16:26:45 2011 +0100
+++ b/lisp/help-macro.el	Wed Sep 07 21:21:36 2011 +0100
@@ -86,24 +86,25 @@
   `(defun ,fname ()
      ,(eval help-text)
      (interactive)
-     (flet ((help-read-key (prompt)
-	      ;; This is in `flet' to avoid problems with autoloading.
-	      ;; #### The function is ill-conceived -- there should be
-	      ;; a way to do it without all the hassle!
-	      (let (events)
-		(while (not (key-press-event-p
-			     (aref (setq events (read-key-sequence prompt)) 0)))
-		  ;; Mouse clicks are not part of the help feature, so
-		  ;; reexecute them in the standard environment.
-		  (mapc 'dispatch-event events))
-		(let ((key (nconc (event-modifiers (aref events 0))
-				  (list (event-key (aref events 0))))))
-		  ;; Make the HELP key translate to C-h.
-		  (when (lookup-key function-key-map key)
-		    (setq key (lookup-key function-key-map key)))
-		  (if (eq (length key) 1)
-		      (car key)
-		    key)))))
+     (labels
+         ((help-read-key (prompt)
+            ;; This is in `labels' to avoid problems with autoloading.
+            ;; #### The function is ill-conceived -- there should be
+            ;; a way to do it without all the hassle!
+            (let (events)
+              (while (not (key-press-event-p
+                           (aref (setq events (read-key-sequence prompt)) 0)))
+                ;; Mouse clicks are not part of the help feature, so
+                ;; reexecute them in the standard environment.
+                (mapc 'dispatch-event events))
+              (let ((key (nconc (event-modifiers (aref events 0))
+                                (list (event-key (aref events 0))))))
+                ;; Make the HELP key translate to C-h.
+                (when (lookup-key function-key-map key)
+                  (setq key (lookup-key function-key-map key)))
+                (if (eq (length key) 1)
+                    (car key)
+                  key)))))
        (let ((line-prompt
 	      (substitute-command-keys ,(eval help-line))))
 	 (when three-step-help